menu
pdf_viewer_plus package
documentation
pdf_flow_view.dart
pdf_flow_view.dart
dark_mode
light_mode
pdf_flow_view
library
Classes
PdfFlowView
A "reading flow" PDF widget that lays out every page as a vertical column of images, sized to the height of its content and
without any internal scrolling of its own
.
pdf_viewer_plus package
documentation
pdf_flow_view.dart
pdf_viewer_plus
package
Libraries
pdf_flow_view
pdf_viewer
pdf_viewer_plus
pdf_flow_view library