errorBuilder property

Widget Function(BuildContext context, Object error)? errorBuilder
final

Builds the widget shown when the document fails to load or parse.

Receives the error that caused the failure. When null, a default error state is shown (a centred error icon).

Implementation

final Widget Function(BuildContext context, Object error)? errorBuilder;