PdfSemanticLabels class
Configurable semantic labels for accessibility in the PDF viewer.
All labels have English defaults. Pass a custom instance to PdfViewer to localise or override the announcements made by screen readers.
Constructors
- PdfSemanticLabels({String toggleSidebar = 'Toggle thumbnail sidebar', String pageLabel(int page, int pageCount) = _defaultPageLabel, String zoomHint = 'Pinch to zoom to enlarge the document', String loadingDocument = 'Loading PDF document', String loadingThumbnails = 'Loading thumbnails', String thumbnailList = 'PDF page thumbnails', String loadingThumbnailsError = 'Error loading thumbnails', String loadingDocumentError = 'Error loading PDF document'})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- loadingDocument → String
-
final
- loadingDocumentError → String
-
final
- loadingThumbnails → String
-
final
- loadingThumbnailsError → String
-
final
- pageLabel → String Function(int page, int pageCount)
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbnailList → String
-
final
- toggleSidebar → String
-
final
- zoomHint → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited